/*
 * File : inputHandler.h
 *
 * Description : This file declares the inputHandler class.
 */

#ifndef _inputHandler_h_
#define _inputHandler_h_

#include "eventHandler.h"

class inputHandler;

/*
 * Class : inputHandler
 *
 * Description : The inputHandler class inherits from eventHandler
 *	and provides the functionality to monitor and handle inputs
 *	on Unix IPC devices. The methods SetEvent and CheckEvent 
 *	are redefined.
 *	Further subclasses will inherit from inputHandler to provide
 * 	functionality for handling input on specific Unix IPC 
 * 	devices.
 *
 * Attributes:
 *	int	_fd: The file descriptor being monitored by this
 *			input handler.
 */

class inputHandler : public eventHandler {
 public:
	inputHandler(int fd) { _fd = fd; }
	int GetFd() { return _fd; }

	void SetEvent(fd_set *readfds,
		fd_set *writefds, fd_set *exceptfds,
		struct timeval *timeout);

	virtual void CheckEvent(fd_set *readfds,
		fd_set *writefds, fd_set *exceptfds,
		struct timeval *curtime);

protected:
	int _fd;
};

#endif
